Name:           jmock
Version:        2.12.0
Release:        %mkrel 6
Group:          Development/Java
Summary:        Java library for testing code with mock objects
License:        BSD
URL:            http://www.jmock.org/
BuildArch:      noarch
#ExclusiveArch:  %%{java_arches} noarch

Source0:        https://github.com/jmock-developers/jmock-library/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         0001-Port-to-jakarta.xml.ws-4.0.0.patch

BuildRequires:  maven-local
BuildRequires:  mvn(cglib:cglib)
BuildRequires:  mvn(com.google.auto.service:auto-service)
BuildRequires:  mvn(com.google.code.findbugs:jsr305)
BuildRequires:  mvn(jakarta.xml.ws:jakarta.xml.ws-api)
BuildRequires:  mvn(junit:junit)
BuildRequires:  mvn(net.bytebuddy:byte-buddy)
BuildRequires:  mvn(org.apache-extras.beanshell:bsh)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-enforcer-plugin)
BuildRequires:  mvn(org.codehaus.mojo:exec-maven-plugin)
BuildRequires:  mvn(org.hamcrest:hamcrest)
BuildRequires:  mvn(org.hamcrest:hamcrest-library)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-api)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-engine)
BuildRequires:  mvn(org.junit.jupiter:junit-jupiter-params)
BuildRequires:  mvn(org.junit.platform:junit-platform-launcher)
BuildRequires:  mvn(org.objenesis:objenesis)
BuildRequires:  mvn(org.ow2.asm:asm)

# required for some unit tests
BuildRequires:  mvn(org.apache.maven.surefire:surefire-junit-platform)

%description
Mock objects help you design and test the interactions between the objects in
your programs.
The jMock library:
  * makes it quick and easy to define mock objects, so you don't break the
    rhythm of programming.
  * lets you precisely specify the interactions between your objects, reducing
    the brittleness of your tests.
  * works well with the auto-completion and re-factoring features of your IDE
  * plugs into your favorite test framework
  * is easy to extend.

%package example
Summary:        jMock Examples
%description example
jMock Examples.

%package imposters
Summary:        jMock imposters
%description imposters
jMock imposters.

%package junit3
Summary:        jMock JUnit 3 Integration
%description junit3
jMock JUnit 3 Integration.

%package junit4
Summary:        jMock JUnit 4 Integration
%description junit4
jMock JUnit 4 Integration.

%package junit5
Summary:        jMock JUnit 5 Integration
%description junit5
jMock JUnit 5 Integration.

%package legacy
Summary:        jMock Legacy Plugins
%description legacy
Plugins that make it easier to use jMock with legacy code.

%package testjar
Summary:        jMock Test Jar
%description testjar
Source for JAR files used in jMock Core tests.

%{?javadoc_package}

%prep
# -p1: strip one level directory in patch
# -n: base directory name
%autosetup -p1 -n %{name}-library-%{version}
# remove unnecessary dependency on parent POM
%pom_remove_parent
# remove maven plugins that are not required for RPM builds
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-source-plugin
%pom_remove_plugin :nexus-staging-maven-plugin
%pom_remove_plugin -r :versions-maven-plugin
%pom_remove_plugin :maven-gpg-plugin testjar
# change dep artifact
%pom_change_dep :jaxws-api jakarta.xml.ws:jakarta.xml.ws-api jmock
# use correct maven artifact for @javax.annotations.Nullable
%pom_change_dep com.google.code.findbugs:annotations com.google.code.findbugs:jsr305 testjar
# don't install imposters-tests and parent package
%mvn_package :jmock-imposters-tests __noinstall
%mvn_package :jmock-parent __noinstall

%build
%mvn_build -s -- -Dmaven.test.failure.ignore=true

%install
%mvn_install

%files           -f .mfiles-%{name}
%doc README*
%license LICENSE.txt
%files example   -f .mfiles-%{name}-example
%files imposters -f .mfiles-%{name}-imposters
%files junit3    -f .mfiles-%{name}-junit3
%files junit4    -f .mfiles-%{name}-junit4
%files junit5    -f .mfiles-%{name}-junit5
%files legacy    -f .mfiles-%{name}-legacy
%files testjar   -f .mfiles-%{name}-testjar
%license LICENSE.txt



%changelog
* Sun Jun 29 2025 umeabot <umeabot> 2.12.0-6.mga10
+ Revision: 2223392
- Mageia 10 Mass Rebuild

* Fri May 24 2024 daviddavid <daviddavid> 2.12.0-5.mga10
+ Revision: 2066901
- Resolve issues related to jakarta.xml.ws 4.0.0
- rebuild for java 21

* Fri Dec 09 2022 daviddavid <daviddavid> 2.12.0-4.mga9
+ Revision: 1919898
- Change BR: jaxws-api to jakarta.xml.ws-api
- Enable enforcer plugin
- Don't install jmock-parent subpackage
- Patch is removed upstream (https://github.com/jmock-developers/jmock-library/commit/6eab2dd8e15c81117bd70ee05c150f6b686f916c)
- Ignore tests failure

* Sat Mar 26 2022 umeabot <umeabot> 2.12.0-3.mga9
+ Revision: 1827687
- Mageia 9 Mass Rebuild

* Sun Jan 24 2021 neoclust <neoclust> 2.12.0-2.mga8
+ Revision: 1673230
- Enabled back tests
- Disable test for now

* Sat Sep 05 2020 daviddavid <daviddavid> 2.12.0-1.mga8
+ Revision: 1622324
- Update to version 2.12.0
- Add jmock-junit4.13.patch to fix test failure with junit4.13
- Allow building against JDK 11
- Rebuilt for JDK-11
- Remove unnecessary dependency on parent POM

* Wed Feb 12 2020 umeabot <umeabot> 2.8.2-4.mga8
+ Revision: 1491382
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 2.8.2-3.mga7
+ Revision: 1263411
- Mageia 7 Mass Rebuild

* Fri May 26 2017 neoclust <neoclust> 2.8.2-2.mga6
+ Revision: 1104798
- Disable tests

* Wed May 17 2017 neoclust <neoclust> 2.8.2-1.mga6
+ Revision: 1102797
- New version 2.8.2
- Second rebuild of the java stack

* Wed Mar 02 2016 neoclust <neoclust> 2.8.1-5.mga6
+ Revision: 981770
- Second rebuild of the java stack

* Tue Feb 23 2016 neoclust <neoclust> 2.8.1-4.mga6
+ Revision: 976430
- First rebuild of the java stack
- sync package jmock with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Fri Jul 03 2015 daviddavid <daviddavid> 2.8.1-1.mga6
+ Revision: 849741
- sync with fc23 (update to 2.8.1)
- fix Group
- fix owner of maven-poms dir

* Wed Oct 15 2014 umeabot <umeabot> 2.5.1-5.mga5
+ Revision: 748765
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ dmorgan <dmorgan>
- Use ojectweb-asm3

* Fri Oct 18 2013 umeabot <umeabot> 2.5.1-2.mga4
+ Revision: 522251
- Mageia 4 Mass Rebuild

* Sun Feb 17 2013 dmorgan <dmorgan> 2.5.1-1.mga3
+ Revision: 398922
- imported package jmock


* Thu Apr 19 2012 gil cattaneo <puntogil@libero.it> 2.5.1-1
- initial rpm
